pub struct Dimension(/* private fields */);Expand description
A positive spatial dimension count.
Implementations
Sourceimpl Dimension
impl Dimension
Sourcepub const fn new_unchecked(value: usize) -> Self
pub const fn new_unchecked(value: usize) -> Self
Creates a dimension count without checking whether it is positive.
Sourcepub const fn is_spatial(self) -> bool
pub const fn is_spatial(self) -> bool
Returns true for dimensions commonly used as spatial geometry.